================================
Welcome to apio's documentation!
================================

.. image:: resources/images/apio-logo-mini.png

Open source **ecosystem for open FPGA boards**. It was inspired by `PlatformIO <https://github.com/platformio/platformio>`_.

Apio (pronounced [ˈa.pjo]) is a **multiplatform toolbox**, with static pre-built packages, project configuration tools and easy command interface to verify, synthesize, simulate and upload your **verilog** designs.

Apio is used by `Icestudio <https://github.com/FPGAwars/icestudio>`_.

**Source code**: https://github.com/FPGAwars/apio

Contents
````````

.. toctree::
   :maxdepth: 2

   source/installation
   source/quick_start
   source/user_guide/index
   source/contribute/index
